@@ -42,6 +42,9 @@ def ParseArgs():
   parser.add_argument('--usage-reporting',
                       default=None, type=Bool,
                       help='(true/false) Disable anonymous usage reporting.')
+  parser.add_argument('--screen-reader',
+                      default=None, type=Bool,
+                      help='(true/false) Disable screen reader mode.')
   parser.add_argument('--rc-path',
                       help=('Profile to update with PATH and completion. If'
                             ' given without --command-completion or'
@@ -108,7 +111,7 @@ To help improve the quality of this product, we collect anonymized usage data
 and anonymized stacktraces when crashes are encountered; additional information
 is available at <https://cloud.google.com/sdk/usage-statistics>. This data is
 handled in accordance with our privacy policy
-<https://policies.google.com/privacy>. You may choose to opt in this
+<https://cloud.google.com/terms/cloud-privacy-notice>. You may choose to opt in this
 collection now (by choosing 'Y' at the below prompt), or at any time in the
 future by running the following command:
 
@@ -189,6 +192,10 @@ the Google Cloud Platform.
 
 def main():
   pargs = ParseArgs()
+  if pargs.screen_reader is not None:
+    properties.PersistProperty(properties.VALUES.accessibility.screen_reader,
+                               pargs.screen_reader,
+                               scope=properties.Scope.INSTALLATION)
   update_manager.RestartIfUsingBundledPython(sdk_root=config.Paths().sdk_root,
                                              command=__file__)
   reinstall_components = encoding.GetEncodedValue(
