@@ -89,7 +89,8 @@ def CreateDiskMessages(args,
                        support_match_container_mount_disks=False,
                        support_create_disk_snapshots=False,
                        support_persistent_attached_disks=True,
-                       support_replica_zones=False):
+                       support_replica_zones=False,
+                       use_disk_type_uri=True):
   """Creates disk messages for a single instance."""
 
   container_mount_disk = []
@@ -125,7 +126,8 @@ def CreateDiskMessages(args,
           resource_policy=support_disk_resource_policy,
           enable_source_snapshot_csek=support_source_snapshot_csek,
           enable_image_csek=support_image_csek,
-          support_replica_zones=support_replica_zones))
+          support_replica_zones=support_replica_zones,
+          use_disk_type_uri=use_disk_type_uri))
 
   local_nvdimms = []
   if support_nvdimm:
@@ -135,7 +137,7 @@ def CreateDiskMessages(args,
 
   local_ssds = CreateLocalSsdMessages(args, resource_parser,
                                       compute_client.messages, location, scope,
-                                      project)
+                                      project, use_disk_type_uri)
   if create_boot_disk:
     boot_snapshot_uri = None
     if support_boot_snapshot_uri:
@@ -243,7 +245,8 @@ def CreatePersistentCreateDiskMessages(compute_client,
                                        resource_policy=False,
                                        enable_source_snapshot_csek=False,
                                        enable_image_csek=False,
-                                       support_replica_zones=False):
+                                       support_replica_zones=False,
+                                       use_disk_type_uri=True):
   """Returns a list of AttachedDisk messages for newly creating disks.
 
   Args:
@@ -274,6 +277,7 @@ def CreatePersistentCreateDiskMessages(compute_client,
     enable_source_snapshot_csek: True if snapshot CSK files are enabled
     enable_image_csek: True if image CSK files are enabled
     support_replica_zones: True if we allow creation of regional disks
+    use_disk_type_uri: True to use disk type URI, False if naked type.
 
   Returns:
     list of API messages for attached disks
@@ -298,11 +302,12 @@ def CreatePersistentCreateDiskMessages(compute_client,
     disk_size_gb = utils.BytesToGb(disk.get('size'))
     disk_type = disk.get('type')
     if disk_type:
-      disk_type_ref = instance_utils.ParseDiskType(resources, disk_type,
-                                                   project, location, scope)
-      disk_type_uri = disk_type_ref.SelfLink()
+      if use_disk_type_uri:
+        disk_type_ref = instance_utils.ParseDiskType(resources, disk_type,
+                                                     project, location, scope)
+        disk_type = disk_type_ref.SelfLink()
     else:
-      disk_type_uri = None
+      disk_type = None
 
     img = disk.get('image')
     img_family = disk.get('image-family')
@@ -337,7 +342,7 @@ def CreatePersistentCreateDiskMessages(compute_client,
         description=disk.get('description'),
         sourceImage=image_uri,
         diskSizeGb=disk_size_gb,
-        diskType=disk_type_uri,
+        diskType=disk_type,
         sourceImageEncryptionKey=image_key)
 
     replica_zones = disk.get('replica-zones')
@@ -407,12 +412,13 @@ def CreateDefaultBootAttachedDiskMessage(compute_client,
                                          csek_keys=None,
                                          kms_args=None,
                                          enable_kms=False,
-                                         snapshot_uri=None):
+                                         snapshot_uri=None,
+                                         use_disk_type_uri=True):
   """Returns an AttachedDisk message for creating a new boot disk."""
   messages = compute_client.messages
   compute = compute_client.apitools_client
 
-  if disk_type:
+  if disk_type and use_disk_type_uri:
     disk_type_ref = instance_utils.ParseDiskType(resources, disk_type, project,
                                                  location, scope)
     disk_type_uri = disk_type_ref.SelfLink()
@@ -544,7 +550,8 @@ def CreateLocalSsdMessages(args,
                            messages,
                            location=None,
                            scope=None,
-                           project=None):
+                           project=None,
+                           use_disk_type_uri=True):
   """Create messages representing local ssds."""
   local_ssds = []
   for local_ssd_disk in getattr(args, 'local_ssd', []) or []:
@@ -552,7 +559,7 @@ def CreateLocalSsdMessages(args,
                                        local_ssd_disk.get('device-name'),
                                        local_ssd_disk.get('interface'),
                                        local_ssd_disk.get('size'), location,
-                                       scope, project)
+                                       scope, project, use_disk_type_uri)
     local_ssds.append(local_ssd)
   return local_ssds
 
@@ -564,10 +571,11 @@ def _CreateLocalSsdMessage(resources,
                            size_bytes=None,
                            location=None,
                            scope=None,
-                           project=None):
+                           project=None,
+                           use_disk_type_uri=True):
   """Create a message representing a local ssd."""
 
-  if location:
+  if location and use_disk_type_uri:
     disk_type_ref = instance_utils.ParseDiskType(resources, 'local-ssd',
                                                  project, location, scope)
     disk_type = disk_type_ref.SelfLink()
@@ -667,7 +675,8 @@ def GetNetworkInterfacesAlpha(args, client, holder, project, location, scope,
   if (skip_defaults and not instance_utils.IsAnySpecified(
       args, 'network', 'subnet', 'private_network_ip', 'no_address', 'address',
       'network_tier', 'no_public_dns', 'public_dns', 'no_public_ptr',
-      'public_ptr', 'no_public_ptr_domain', 'public_ptr_domain')):
+      'public_ptr', 'no_public_ptr_domain', 'public_ptr_domain', 'stack_type',
+      'ipv6_network_tier')):
     return []
   return [
       CreateNetworkInterfaceMessage(
@@ -687,7 +696,9 @@ def GetNetworkInterfacesAlpha(args, client, holder, project, location, scope,
           no_public_ptr=getattr(args, 'no_public_ptr', None),
           public_ptr=getattr(args, 'public_ptr', None),
           no_public_ptr_domain=getattr(args, 'no_public_ptr_domain', None),
-          public_ptr_domain=getattr(args, 'public_ptr_domain', None))
+          public_ptr_domain=getattr(args, 'public_ptr_domain', None),
+          stack_type=getattr(args, 'stack_type', None),
+          ipv6_network_tier=getattr(args, 'ipv6_network_tier', None))
   ]
 
 
@@ -709,7 +720,9 @@ def CreateNetworkInterfaceMessage(resources,
                                   no_public_ptr=None,
                                   public_ptr=None,
                                   no_public_ptr_domain=None,
-                                  public_ptr_domain=None):
+                                  public_ptr_domain=None,
+                                  stack_type=None,
+                                  ipv6_network_tier=None):
   """Returns a new NetworkInterface message."""
   # TODO(b/30460572): instance reference should have zone name, not zone URI.
   if scope == compute_scopes.ScopeEnum.ZONE:
@@ -754,14 +767,18 @@ def CreateNetworkInterfaceMessage(resources,
           resources, private_network_ip, region).SelfLink()
 
   if nic_type is not None:
-    network_interface.nicType = messages.NetworkInterface.NicTypeValueValuesEnum(
-        nic_type)
+    network_interface.nicType = (
+        messages.NetworkInterface.NicTypeValueValuesEnum(nic_type))
 
   if alias_ip_ranges_string:
     network_interface.aliasIpRanges = (
         alias_ip_range_utils.CreateAliasIpRangeMessagesFromString(
             messages, True, alias_ip_ranges_string))
 
+  if stack_type is not None:
+    network_interface.stackType = messages.NetworkInterface.StackTypeValueValuesEnum(
+        stack_type)
+
   if not no_address:
     access_config = messages.AccessConfig(
         name=constants.DEFAULT_ACCESS_CONFIG_NAME,
@@ -772,7 +789,6 @@ def CreateNetworkInterfaceMessage(resources,
 
     # If the user provided an external IP, populate the access
     # config with it.
-    # TODO(b/25278937): plays poorly when creating multiple instances
     address_resource = instances_flags.ExpandAddressFlag(
         resources, compute_client, address, region)
     if address_resource:
@@ -793,6 +809,15 @@ def CreateNetworkInterfaceMessage(resources,
 
     network_interface.accessConfigs = [access_config]
 
+  if ipv6_network_tier is not None:
+    ipv6_access_config = messages.AccessConfig(
+        name=constants.DEFAULT_IPV6_ACCESS_CONFIG_NAME,
+        type=messages.AccessConfig.TypeValueValuesEnum.DIRECT_IPV6)
+    ipv6_access_config.networkTier = (
+        messages.AccessConfig.NetworkTierValueValuesEnum(ipv6_network_tier))
+
+    network_interface.ipv6AccessConfigs = [ipv6_access_config]
+
   return network_interface
 
 
@@ -845,7 +870,9 @@ def GetNetworkInterfacesWithValidation(args,
                                        location,
                                        scope,
                                        skip_defaults,
-                                       support_public_dns=False):
+                                       support_public_dns=False,
+                                       support_stack_type=False,
+                                       support_ipv6_network_tier=False):
   """Validates and retrieves the network interface message."""
   if args.network_interface:
     return CreateNetworkInterfaceMessages(
@@ -857,8 +884,9 @@ def GetNetworkInterfacesWithValidation(args,
         scope=scope)
   else:
     instances_flags.ValidatePublicPtrFlags(args)
-    if support_public_dns:
-      instances_flags.ValidatePublicDnsFlags(args)
+    if support_public_dns or support_stack_type or support_ipv6_network_tier:
+      if support_public_dns:
+        instances_flags.ValidatePublicDnsFlags(args)
       return GetNetworkInterfacesAlpha(args, compute_client, holder, project,
                                        location, scope, skip_defaults)
     return GetNetworkInterfaces(args, compute_client, holder, project, location,
@@ -976,6 +1004,15 @@ def GetAccelerators(args, compute_client, resource_parser, project, location,
   return []
 
 
+def GetAcceleratorsForInstanceProperties(args, compute_client):
+  if args.accelerator:
+    accelerator_type = args.accelerator['type']
+    accelerator_count = int(args.accelerator.get('count', 1))
+    return CreateAcceleratorConfigMessages(compute_client.messages,
+                                           accelerator_type, accelerator_count)
+  return []
+
+
 def CreateAcceleratorConfigMessages(msgs, accelerator_type, accelerator_count):
   """Returns a list of accelerator config messages.
 
@@ -994,8 +1031,13 @@ def CreateAcceleratorConfigMessages(msgs, accelerator_type, accelerator_count):
   return [accelerator_config]
 
 
-def CreateMachineTypeUri(args, compute_client, resource_parser, project,
-                         location, scope, confidential_vm=False):
+def CreateMachineTypeUri(args,
+                         compute_client,
+                         resource_parser,
+                         project,
+                         location,
+                         scope,
+                         confidential_vm=False):
   """Create a machine type URI for given args and instance reference."""
 
   machine_type = args.machine_type
