@@ -24,6 +24,7 @@ import collections
 from googlecloudsdk.api_lib.events import iam_util
 from googlecloudsdk.api_lib.events import trigger
 from googlecloudsdk.calliope import arg_parsers
+from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions as calliope_exceptions
 from googlecloudsdk.command_lib.events import exceptions
 from googlecloudsdk.command_lib.iam import iam_util as core_iam_util
@@ -43,11 +44,13 @@ def AddSourceFlag(parser):
       help='Events source kind by which to filter results.')
 
 
-def AddEventTypePositionalArg(parser):
+def AddEventTypePositionalArg(parser, release_track):
   """Adds event type positional arg."""
-  parser.add_argument(
-      'event_type',
-      help='Type of event (e.g. com.google.cloud.auditlog.event).')
+  if release_track == base.ReleaseTrack.ALPHA:
+    help_text = 'Type of event (e.g. com.google.cloud.auditlog.event).'
+  else:
+    help_text = 'Type of event (e.g. google.cloud.audit.log.v1.written).'
+  parser.add_argument('event_type', help=help_text)
 
 
 def AddTargetServiceFlag(parser, required=False):
@@ -56,15 +59,17 @@ def AddTargetServiceFlag(parser, required=False):
       '--target-service',
       required=required,
       help='Name or absolute uri of the Cloud Run service at which '
-      'events should be received.')
+      'events should be received. (e.g. service-name or '
+      'http://service-name.default.svc.cluster.local)')
 
 
-def AddEventTypeFlagArg(parser):
+def AddEventTypeFlagArg(parser, release_track):
   """Adds event type flag arg."""
-  parser.add_argument(
-      '--type',
-      required=True,
-      help='Type of event (e.g. com.google.cloud.auditlog.event).')
+  if release_track == base.ReleaseTrack.ALPHA:
+    help_text = 'Type of event (e.g. com.google.cloud.auditlog.event).'
+  else:
+    help_text = 'Type of event (e.g. google.cloud.audit.log.v1.written).'
+  parser.add_argument('--type', required=True, help=help_text)
 
 
 def AddBrokerFlag(parser):
@@ -210,6 +215,59 @@ def _ParseSecretParameters(args):
   return secret_params
 
 
+_RESOURCES_FLAG_NAME = 'resources'
+
+
+def AddResourcesFlag(parser):
+  """Adds resources flag."""
+  parser.add_argument(
+      '--{}'.format(_RESOURCES_FLAG_NAME),
+      action='append',
+      help='Comma-separated list of secret parameter names and secrets. '
+      'Specify secret parameters and the secret name and key to '
+      'reference. Parameter names must be one of the secret parameters shown '
+      'when describing the event type.',
+      metavar='PARAMETER=NAME:KEY')
+
+
+def _ParseResourcesParameters(args):
+  """Parses --resources flag."""
+
+  resources_flag = getattr(args, _RESOURCES_FLAG_NAME)
+
+  if resources_flag is None:
+    return {}
+
+  result = []
+  for api_version_kind_string in resources_flag:
+    avk_selector = api_version_kind_string.split(':')
+    if len(avk_selector) != 3 and len(avk_selector) != 2:
+      raise run_flags.ArgumentError('parameter flag resources expects Kind:'
+                                    'ApiVersion:LabelName=value, notation.')
+    elif len(avk_selector) == 2:
+      result.append({
+          'kind': avk_selector[0],
+          'apiVersion': avk_selector[1],
+      })
+    elif len(avk_selector) == 3:
+      match_labels_obj = {}
+      for match_labels_string in avk_selector[2].split(','):
+        key, value = match_labels_string.split('=')
+        match_labels_obj[key] = value
+      result.append({
+          'kind': avk_selector[0],
+          'apiVersion': avk_selector[1],
+          'selector': {
+              'matchLabels': match_labels_obj,
+          }
+      })
+
+  resources_params = {}
+  if result:
+    resources_params['resources'] = result
+  return resources_params
+
+
 def _CheckUnknownParameters(event_type, known_params, given_params):
   """Raises an error if any given params are unknown."""
   unknown_parameters = (
@@ -252,6 +310,10 @@ def GetAndValidateParameters(args, event_type):
     parameters.update(getattr(args, from_file_flag))
   if args.IsSpecified(_PARAMETERS_FLAG_NAME):
     parameters.update(getattr(args, _PARAMETERS_FLAG_NAME))
+
+  resource_parameters = _ParseResourcesParameters(args)
+  parameters.update(resource_parameters)
+
   _ValidateParameters(event_type, parameters)
 
   # Check the passed secret parameters for unknown keys or missing required keys
