@@ -21,6 +21,9 @@ import abc
 
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
+from googlecloudsdk.core import log
+from googlecloudsdk.core import properties
+from googlecloudsdk.core.console import console_io
 
 import six
 
@@ -65,6 +68,23 @@ class StringFlag(BinaryCommandFlag):
     return []
 
 
+class StringListFlag(BinaryCommandFlag):
+  """A flag that takes in a string list value passed directly through to the binary."""
+
+  def __init__(self, name, *args, **kwargs):
+    super(StringListFlag, self).__init__()
+    self.arg = base.Argument(name, *args, type=arg_parsers.ArgList(), **kwargs)
+
+  def AddToParser(self, parser):
+    return self.arg.AddToParser(parser)
+
+  def FormatFlags(self, args):
+    dest_name = _GetDestNameForFlag(self.arg.name)
+    if args.IsSpecified(dest_name):
+      return [self.arg.name, ','.join(getattr(args, dest_name))]
+    return []
+
+
 class BooleanFlag(BinaryCommandFlag):
   """Encapsulates a boolean flag that can be either --<flag> or --no-<flag>."""
 
@@ -198,18 +218,11 @@ class ClusterConnectionFlags(BinaryCommandFlag):
 class TrafficFlags(BinaryCommandFlag):
   """Encapsulates flags to configure traffic routes to the service."""
 
-  def AddToParser(self, parser):
-    mutex_group = parser.add_mutually_exclusive_group(required=True)
-    mutex_group.add_argument(
-        '--to-latest',
-        default=False,
-        action='store_true',
-        help='If true, assign 100 percent of traffic to the \'latest\' revision '
-        'of this service. Note that when a new revision is created, it will '
-        'become the \'latest\' and traffic will be directed to it. Defaults to '
-        'False. Synonymous with `--to-revisions=LATEST=100`.')
-    mutex_group.add_argument(
+  def __init__(self):
+    super(TrafficFlags, self).__init__()
+    self.to_revisions_flag = StringListFlag(
         '--to-revisions',
+        metavar='REVISION-NAME=PERCENTAGE',
         help='Comma-separated list of traffic assignments in the form '
         'REVISION-NAME=PERCENTAGE. REVISION-NAME must be the name for a revision '
         'for the service as returned by \'gcloud kuberun core revisions list\'. '
@@ -228,11 +241,31 @@ class TrafficFlags(BinaryCommandFlag):
         '"LATEST" as a special revision name to always put the given percentage '
         'of traffic on the latest ready revision.')
 
+  def AddToParser(self, parser):
+    mutex_group = parser.add_mutually_exclusive_group(required=True)
+    mutex_group.add_argument(
+        '--to-latest',
+        default=False,
+        action='store_true',
+        help='If true, assign 100 percent of traffic to the \'latest\' revision '
+        'of this service. Note that when a new revision is created, it will '
+        'become the \'latest\' and traffic will be directed to it. Defaults to '
+        'False. Synonymous with `--to-revisions=LATEST=100`.')
+
+    self.to_revisions_flag.AddToParser(mutex_group)
+
   def FormatFlags(self, args):
     if args.IsSpecified('to_latest'):
       return ['--to-latest']
     elif args.IsSpecified('to_revisions'):
-      return ['--to-revisions', args.to_revisions]
+      return self.to_revisions_flag.FormatFlags(args)
+
+
+def CreateIfMissingFlag():
+  return BasicFlag(
+      '--create-if-missing',
+      help="Creates the service if it's missing. If set, `--image` must be set as well."
+  )
 
 
 def CommonServiceFlags(is_create=False):
@@ -287,15 +320,17 @@ def ConcurrencyFlag():
 
 def EntrypointFlags():
   """Encapsulate flags for customizing container command."""
-  args_flag = StringFlag(
+  args_flag = StringListFlag(
       '--args',
+      metavar='ARG',
       help='Comma-separated arguments passed to the command run by the '
       "container image. If not specified and no '--command' is provided, the "
       "container image's default Cmd is used. Otherwise, if not specified, no "
       'arguments are passed. To reset this field to its default, pass an empty '
       'string.')
-  command_flag = StringFlag(
+  command_flag = StringListFlag(
       '--command',
+      metavar='COMMAND',
       help='Entrypoint for the container image. If not specified, the '
       "container image's default Entrypoint is run. To reset this field to its "
       'default, pass an empty string.')
@@ -317,11 +352,12 @@ def ScalingFlags():
 class ResourceListFlagGroup(BinaryCommandFlag):
   """Encapsulates create/set/update/remove key-value flags."""
 
-  def __init__(self,
-               name,
-               help=None,  # pylint: disable=redefined-builtin
-               help_name=None,
-               set_flag_only=False):
+  def __init__(
+      self,
+      name,
+      help=None,  # pylint: disable=redefined-builtin
+      help_name=None,
+      set_flag_only=False):
     """Create a new resource list flag group.
 
     Args:
@@ -332,63 +368,58 @@ class ResourceListFlagGroup(BinaryCommandFlag):
     """
     super(ResourceListFlagGroup, self).__init__()
     self.set_flag_only = set_flag_only
-    self.name = name
     self.help = help if not help else help + '\n\n'
-    self.help_name = name if help_name is None else help_name
-    self.clear_flag = '--clear-{}'.format(name)
-    self.set_flag = '--set-{}'.format(name)
-    self.remove_flag = '--remove-{}'.format(name)
-    self.update_flag = '--update-{}'.format(name)
+    help_name = name if help_name is None else help_name
+
+    pairs_help = 'List of key-value pairs to set as {}.'.format(help_name)
+    set_help = pairs_help
+    if set_flag_only:
+      if help:
+        set_help += '\n\n' + help
+    else:
+      set_help += ' All existing {} will be removed first.'.format(help_name)
+
+    self.clear_flag = BasicFlag(
+        '--clear-{}'.format(name),
+        help='If true, removes all {}.'.format(help_name))
+    self.set_flag = StringListFlag(
+        '--set-{}'.format(name), metavar='KEY=VALUE', help=set_help)
+    self.remove_flag = StringListFlag(
+        '--remove-{}'.format(name),
+        metavar='KEY',
+        help='List of {} to be removed.'.format(help_name))
+    update_aliases = []
+    if name == 'labels':
+      # Added for compatibility reasons with gcloud run services update
+      update_aliases.append('--labels')
+    self.update_flag = StringListFlag(
+        '--update-{}'.format(name),
+        *update_aliases,
+        metavar='KEY=VALUE',
+        help=pairs_help)
 
   def AddToParser(self, parser):
-    pairs_help = 'List of KEY=VALUE pairs to set as {}.'.format(self.help_name)
-    set_help = pairs_help
     if self.set_flag_only:
-      if self.help:
-        set_help += '\n\n' + self.help
-      parser.add_argument(self.set_flag, help=set_help)
+      self.set_flag.AddToParser(parser)
       return
 
-    set_help += ' All existing {} will be removed first.'.format(self.help_name)
     mutex_group = parser.add_mutually_exclusive_group(help=self.help)
-    mutex_group.add_argument(
-        self.clear_flag,
-        default=False,
-        action='store_true',
-        help='If true, removes all {}.'.format(self.help_name))
-    mutex_group.add_argument(self.set_flag, help=set_help)
+    self.clear_flag.AddToParser(mutex_group)
+    self.set_flag.AddToParser(mutex_group)
     update_group = mutex_group.add_group(
         help='Only `{update}` and `{remove}` can be used together. '
         'If both are specified, `{remove}` will be applied first.'.format(
-            update=self.update_flag, remove=self.remove_flag))
-    update_group.add_argument(
-        self.remove_flag,
-        help='List of {} to be removed.'.format(self.help_name))
-    update_aliases = []
-    if self.name == 'labels':
-      # Added for compatibility reasons with gcloud run services update
-      update_aliases.append('--labels')
-    update_group.add_argument(
-        self.update_flag,
-        *update_aliases,
-        help=pairs_help)
+            update=self.update_flag.arg.name, remove=self.remove_flag.arg.name))
+    self.remove_flag.AddToParser(update_group)
+    self.update_flag.AddToParser(update_group)
 
   def FormatFlags(self, args):
-    command_flags = []
-    set_dest = _GetDestNameForFlag(self.set_flag)
-    if args.IsSpecified(set_dest):
-      command_flags.extend([self.set_flag, getattr(args, set_dest)])
-
     if self.set_flag_only:
-      return command_flags
-
-    if args.IsSpecified(_GetDestNameForFlag(self.clear_flag)):
-      command_flags.append(self.clear_flag)
-    for flag in [self.remove_flag, self.update_flag]:
-      dest = _GetDestNameForFlag(flag)
-      if args.IsSpecified(dest):
-        command_flags.extend([flag, getattr(args, dest)])
-    return command_flags
+      return self.set_flag.FormatFlags(args)
+    return (self.clear_flag.FormatFlags(args) +
+            self.set_flag.FormatFlags(args) +
+            self.remove_flag.FormatFlags(args) +
+            self.update_flag.FormatFlags(args))
 
 
 def LabelsFlags(set_flag_only=False):
@@ -506,3 +537,43 @@ def RegisterFlags(parser, flags):
 
 def _GetDestNameForFlag(flag):
   return flag.replace('--', '').replace('-', '_')
+
+
+def _GetEnvironment(args):
+  """Prompt for environment if not provided.
+
+  Environment is decided in the following order:
+  - environment argument;
+  - kuberun/environment gcloud config;
+  - prompt user.
+
+  Args:
+    args: Environment, The args environment.
+
+  Returns:
+    A str representing the environment name.
+
+  Raises:
+    A ValueError if no environment is specified.
+  """
+  env = None
+  if getattr(args, 'environment', None):
+    env = args.environment
+  elif properties.VALUES.kuberun.environment.IsExplicitlySet():
+    env = properties.VALUES.kuberun.environment.Get()
+  elif console_io.CanPrompt():
+    env = console_io.PromptWithDefault('Environment name:  ', default=None)
+    log.status.Print(
+        'To make this the default environment, run '
+        '`gcloud config set kuberun/environment {}`.\n'.format(env))
+  if env:
+    return env
+  raise ValueError('Please specify an ENVIRONMENT to use this command.')
+
+
+class EnvironmentFlags(StringFlag):
+  """Formats an environment flag by pulling it from the appropriate source."""
+
+  def FormatFlags(self, args):
+    env = _GetEnvironment(args)
+    return ['--environment', env]
