@@ -19,34 +19,51 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+from googlecloudsdk.command_lib.storage import errors
 from googlecloudsdk.command_lib.storage import plurality_checkable_iterator
 from googlecloudsdk.command_lib.storage import storage_url
 from googlecloudsdk.command_lib.storage import wildcard_iterator
 from googlecloudsdk.command_lib.storage.resources import resource_reference
 from googlecloudsdk.command_lib.storage.tasks.cp import copy_task_factory
+from googlecloudsdk.core import log
 
 
 class CopyTaskIterator:
   """Iterates over each expanded source and creates an appropriate copy task."""
 
-  def __init__(self, source_name_iterator, destination_string):
+  def __init__(self,
+               source_name_iterator,
+               destination_string,
+               custom_md5_digest=None):
     """Initializes a CopyTaskIterator instance.
 
     Args:
       source_name_iterator (name_expansion.NameExpansionIterator):
         yields resource_reference.Resource objects with expanded source URLs.
       destination_string (str): The copy destination path/url.
+      custom_md5_digest (str|None): User-added MD5 hash output to send to server
+          for validating a single resource upload.
     """
     self._source_name_iterator = (
         plurality_checkable_iterator.PluralityCheckableIterator(
             source_name_iterator))
     self._multiple_sources = self._source_name_iterator.is_plural()
     self._destination_string = destination_string
+    self._custom_md5_digest = custom_md5_digest
+
+    if self._multiple_sources and self._custom_md5_digest:
+      raise ValueError('Received multiple objects to upload, but only one'
+                       'custom MD5 digest is allowed.')
 
   def __iter__(self):
     raw_destination = self._get_raw_destination()
     for source in self._source_name_iterator:
       destination_resource = self._get_copy_destination(raw_destination, source)
+      log.status.Print('Copying {} to {}'.format(
+          source.resource.storage_url.versionless_url_string,
+          destination_resource.storage_url.versionless_url_string))
+      if self._custom_md5_digest:
+        source.resource.md5_hash = self._custom_md5_digest
       yield copy_task_factory.get_copy_task(source.resource,
                                             destination_resource)
 
@@ -125,7 +142,7 @@ class CopyTaskIterator:
   def _destination_is_container(self, destination):
     try:
       return destination.is_container()
-    except NotImplementedError:
+    except errors.ValueCannotBeDeterminedError:
       # Some resource classes are not clearly containers. In these cases we need
       # to use the storage_url attribute to infer how to treat them.
       destination_url = destination.storage_url
@@ -198,7 +215,8 @@ class CopyTaskIterator:
       (str) The suffix to be appended to the destination container.
     """
     source_prefix_to_ignore = storage_url.rstrip_one_delimiter(
-        source.expanded_url.versionless_url_string)
+        source.expanded_url.versionless_url_string,
+        source.expanded_url.delimiter)
     if (not isinstance(destination_container,
                        resource_reference.UnknownResource) and
         destination_container.is_container()):
@@ -207,6 +225,12 @@ class CopyTaskIterator:
       # Remove the leaf name so that it gets added to the destination.
       source_prefix_to_ignore = source_prefix_to_ignore.rpartition(
           source.expanded_url.delimiter)[0]
+      if not source_prefix_to_ignore:
+        # In case of Windows, the source URL might not contain any Windows
+        # delimiter if it was a single directory (e.g file://dir) and
+        # source_prefix_to_ignore will be empty. Set it to <scheme>://.
+        # TODO(b/169093672) This will not be required if we get rid of file://
+        source_prefix_to_ignore = source.expanded_url.scheme.value + '://'
 
     full_source_url = source.resource.storage_url.versionless_url_string
     suffix_for_destination = full_source_url.split(source_prefix_to_ignore)[1]
