@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2018 Google Inc. All Rights Reserved.
+# Copyright 2018 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,10 +22,14 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
-@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA,
+                    base.ReleaseTrack.GA)
 class Asset(base.Group):
   """Manage the Cloud Asset Inventory."""
 
+  category = base.SECURITY_CATEGORY
+
   def Filter(self, context, args):
+    """Runs before any commands in this group."""
     del context, args
-    base.DisableUserProjectQuota()
+    base.OptInRequests()  # For b/168048261 migration.
