@@ -178,6 +178,7 @@ information on how to structure KEYs and VALUEs, run
       version will be selected. The version numbers that are used will
       be stored.""")
   flags.AddIpAliasEnvironmentFlags(parser)
+  flags.AddPrivateIpEnvironmentFlags(parser)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
@@ -191,19 +192,16 @@ class Create(base.Command):
   """
 
   detailed_help = DETAILED_HELP
-  _support_web_server_cloud_sql_private_ip_ranges = True
   _support_web_server_access_control = False
 
   @staticmethod
   def Args(parser):
     _CommonArgs(parser)
-    flags.AddPrivateIpEnvironmentFlags(parser, True)
 
   def Run(self, args):
     self.ParseIpAliasConfigOptions(args)
     self.ParsePrivateEnvironmentConfigOptions(args)
-    if self._support_web_server_cloud_sql_private_ip_ranges:
-      self.ParsePrivateEnvironmentWebServerCloudSqlRanges(args)
+    self.ParsePrivateEnvironmentWebServerCloudSqlRanges(args)
 
     flags.ValidateDiskSize('--disk-size', args.disk_size)
     self.env_ref = args.CONCEPTS.environment.Parse()
@@ -366,9 +364,18 @@ class CreateBeta(Create):
 
     flags.WEB_SERVER_MACHINE_TYPE.AddToParser(parser)
 
+    permission_info = '{} must hold permission {}'.format(
+        "The 'Cloud Composer Service Agent' service account",
+        "'Cloud KMS CryptoKey Encrypter/Decrypter'")
+    kms_resource_args.AddKmsKeyResourceArg(
+        parser, 'environment', permission_info=permission_info)
+
   def Run(self, args):
     if self._support_web_server_access_control:
       self.ParseWebServerAccessControlConfigOptions(args)
+    self.kms_key = None
+    if args.kms_key:
+      self.kms_key = flags.GetAndValidateKmsEncryptionKey(args)
     return super(CreateBeta, self).Run(args)
 
   def ParseWebServerAccessControlConfigOptions(self, args):
@@ -410,6 +417,7 @@ class CreateBeta(Create):
         services_secondary_range_name=args.services_secondary_range_name,
         cluster_ipv4_cidr_block=args.cluster_ipv4_cidr,
         services_ipv4_cidr_block=args.services_ipv4_cidr,
+        kms_key=self.kms_key,
         private_environment=args.enable_private_environment,
         private_endpoint=args.enable_private_endpoint,
         master_ipv4_cidr=args.master_ipv4_cidr,
@@ -431,17 +439,11 @@ class CreateAlpha(CreateBeta):
     {top_command} composer operations describe
   """
 
-  _support_web_server_cloud_sql_private_ip_ranges = False
-  _support_web_server_access_control = False
+  _support_web_server_access_control = True
 
   @staticmethod
   def Args(parser):
-    _CommonArgs(parser)
-    flags.CLOUD_SQL_MACHINE_TYPE.AddToParser(parser)
-    flags.WEB_SERVER_MACHINE_TYPE.AddToParser(parser)
-
-    # Private IP falgs without ranges missing in alpha.
-    flags.AddPrivateIpEnvironmentFlags(parser, False)
+    CreateBeta.Args(parser)
 
     # Adding alpha arguments
     parser.add_argument(
@@ -455,20 +457,6 @@ class CreateAlpha(CreateBeta):
         currently supported executor types are CELERY and KUBERNETES.
         Defaults to CELERY. Cannot be updated.""")
 
-    # Workaround to add hidden resource flag, as per b/130564349.
-    group_parser = parser.add_argument_group(hidden=True)
-    permission_info = '{} must hold permission {}'.format(
-        "The 'Cloud Composer Service Agent' service account",
-        "'Cloud KMS CryptoKey Encrypter/Decrypter'")
-    kms_resource_args.AddKmsKeyResourceArg(
-        group_parser, 'environment', permission_info=permission_info)
-
-  def Run(self, args):
-    self.kms_key = None
-    if args.kms_key:
-      self.kms_key = flags.GetAndValidateKmsEncryptionKey(args)
-    return super(CreateAlpha, self).Run(args)
-
   def GetOperationMessage(self, args):
     """See base class."""
     return environments_api_util.Create(
@@ -496,7 +484,10 @@ class CreateAlpha(CreateBeta):
         kms_key=self.kms_key,
         private_environment=args.enable_private_environment,
         private_endpoint=args.enable_private_endpoint,
+        web_server_ipv4_cidr=args.web_server_ipv4_cidr,
+        cloud_sql_ipv4_cidr=args.cloud_sql_ipv4_cidr,
         master_ipv4_cidr=args.master_ipv4_cidr,
+        web_server_access_control=self.web_server_access_control,
         cloud_sql_machine_type=args.cloud_sql_machine_type,
         web_server_machine_type=args.web_server_machine_type,
         release_track=self.ReleaseTrack())
