@@ -64,6 +64,7 @@ def _Args(parser,
   instances_flags.AddKonletArgs(parser)
   instances_flags.AddPublicPtrArgs(parser, instance=True)
   instances_flags.AddImageArgs(parser)
+  instances_flags.AddConfidentialComputeArgs(parser)
   labels_util.AddCreateLabelsFlags(parser)
 
   parser.add_argument(
@@ -85,6 +86,8 @@ class CreateWithContainer(base.CreateCommand):
   _support_create_boot_disk = True
   _support_match_container_mount_disks = True
   _support_nvdimm = False
+  _support_enable_nested_virtualization = False
+  _support_threads_per_core = False
 
   @staticmethod
   def Args(parser):
@@ -191,6 +194,8 @@ class CreateWithContainer(base.CreateCommand):
     can_ip_forward = instance_utils.GetCanIpForward(args, skip_defaults)
     tags = containers_utils.CreateTagsMessage(compute_client.messages,
                                               args.tags)
+    confidential_vm = (
+        args.IsSpecified('confidential_compute') and args.confidential_compute)
 
     requests = []
     for instance_ref in instance_refs:
@@ -227,7 +232,8 @@ class CreateWithContainer(base.CreateCommand):
             resource_parser=resource_parser,
             project=instance_ref.project,
             location=instance_ref.zone,
-            scope=compute_scopes.ScopeEnum.ZONE)
+            scope=compute_scopes.ScopeEnum.ZONE,
+            confidential_vm=confidential_vm)
 
       guest_accelerators = create_utils.GetAccelerators(
           args=args,
@@ -257,6 +263,21 @@ class CreateWithContainer(base.CreateCommand):
                 compute_client.messages).GetEnumForChoice(
                     args.private_ipv6_google_access_type))
 
+      confidential_instance_config = (
+          create_utils.BuildConfidentialInstanceConfigMessage(
+              messages=compute_client.messages, args=args))
+      if confidential_instance_config:
+        instance.confidentialInstanceConfig = confidential_instance_config
+
+      if ((self._support_enable_nested_virtualization and
+           args.enable_nested_virtualization is not None) or
+          (self._support_threads_per_core and
+           args.threads_per_core is not None)):
+        instance.advancedMachineFeatures = (
+            instance_utils.CreateAdvancedMachineFeaturesMessage(
+                compute_client.messages, args.enable_nested_virtualization,
+                args.threads_per_core))
+
       request = compute_client.messages.ComputeInstancesInsertRequest(
           instance=instance,
           sourceInstanceTemplate=source_instance_template,
@@ -277,6 +298,8 @@ class CreateWithContainerBeta(CreateWithContainer):
   _support_create_boot_disk = True
   _support_match_container_mount_disks = True
   _support_nvdimm = False
+  _support_enable_nested_virtualization = False
+  _support_threads_per_core = False
 
   @staticmethod
   def Args(parser):
@@ -300,6 +323,8 @@ class CreateWithContainerAlpha(CreateWithContainerBeta):
   _support_create_boot_disk = True
   _support_match_container_mount_disks = True
   _support_nvdimm = True
+  _support_enable_nested_virtualization = True
+  _support_threads_per_core = True
 
   @staticmethod
   def Args(parser):
@@ -313,6 +338,10 @@ class CreateWithContainerAlpha(CreateWithContainerBeta):
     instances_flags.AddPublicDnsArgs(parser, instance=True)
     instances_flags.AddPrivateIpv6GoogleAccessArg(
         parser, utils.COMPUTE_ALPHA_API_VERSION)
+    instances_flags.AddNestedVirtualizationArgs(parser)
+    instances_flags.AddThreadsPerCoreArgs(parser)
+    instances_flags.AddStackTypeArgs(parser)
+    instances_flags.AddIpv6NetworkTierArgs(parser)
 
   def _ValidateTrackSpecificArgs(self, args):
     instances_flags.ValidateLocalSsdFlags(args)
@@ -329,12 +358,12 @@ class CreateWithContainerAlpha(CreateWithContainerBeta):
 CreateWithContainer.detailed_help = {
     'brief':
         """\
-    Creates Google Compute engine virtual machine instances running
+    Creates Compute Engine virtual machine instances running
     container images.
     """,
     'DESCRIPTION':
         """\
-        *{command}* creates Google Compute Engine virtual
+        *{command}* creates Compute Engine virtual
         machines that runs a Docker image. For example:
 
           $ {command} instance-1 --zone us-central1-a \
