@@ -121,10 +121,18 @@ Cannot be used with the "--create-subnetwork" option.
       'and firewalls for the clusters. Defaults to the \'default\' network.')
   parser.add_argument(
       '--cluster-ipv4-cidr',
-      help='The IP address range for the pods in this cluster in CIDR '
-      'notation (e.g. 10.0.0.0/14).  Prior to Kubernetes version 1.7.0 '
-      'this must be a subset of 10.0.0.0/8; however, starting with version '
-      '1.7.0 can be any RFC 1918 IP range.')
+      help="""\
+The IP address range for the pods in this cluster in CIDR notation (e.g.
+10.0.0.0/14). Prior to Kubernetes version 1.7.0 this must be a subset of
+10.0.0.0/8; however, starting with version 1.7.0 can be any RFC 1918 IP range.
+
+If you omit this option, a range is chosen automatically.  The automatically
+chosen range is randomly selected from 1.0.0.0/8 and will not include IP
+address ranges allocated to VMs, existing routes, or ranges allocated to other
+clusters. The automatically chosen range might conflict with reserved IP
+addresses, dynamic routes, or routes within VPCs that peer with this cluster.
+You should specify `--cluster-ipv4-cidr` to prevent conflicts.
+""")
 
   parser.display_info.AddFormat(util.CLUSTERS_FORMAT)
 
@@ -140,6 +148,31 @@ def MaybeLogAuthWarning(args):
                   'treat that as `--no-enable-basic-auth`.')
 
 
+def _IsSpecified(args, name):
+  """Returns true if an arg is defined and specified, false otherwise."""
+  return hasattr(args, name) and args.IsSpecified(name)
+
+
+def MaybeLogReleaseChannelDefaultWarning(args):
+  """Logs a release channel default change message for applicable commands."""
+  if (
+      not _IsSpecified(args, 'cluster_version') and
+      not _IsSpecified(args, 'release_channel') and
+      (
+          hasattr(args, 'enable_autoupgrade') and
+          cmd_util.GetAutoUpgrade(args)
+      ) and
+      (
+          hasattr(args, 'enable_autorepair') and
+          cmd_util.GetAutoRepair(args)
+      )
+  ):
+    log.warning('Starting in January 2021, clusters will use the Regular '
+                'release channel by default when `--cluster-version`, '
+                '`--release-channel`, `--no-enable-autoupgrade`, and '
+                '`--no-enable-autorepair` flags are not specified.')
+
+
 cloudNatTemplate = string.Template(
     'Autopilot nodes are private. If you need connectivity to the '
     'public internet, for example to pull public containers, you must configure'
@@ -173,12 +206,13 @@ def ParseCreateOptionsBase(args, is_autogke, get_default, location, project_id):
   flags.LogBasicAuthDeprecationWarning(args)
   flags.MungeBasicAuthFlags(args)
   MaybeLogAuthWarning(args)
+  MaybeLogReleaseChannelDefaultWarning(args)
 
   enable_ip_alias = get_default('enable_ip_alias')
   if hasattr(args, 'enable_ip_alias'):
     flags.WarnForUnspecifiedIpAllocationPolicy(args)
 
-  enable_autorepair = False
+  enable_autorepair = None
   if hasattr(args, 'enable_autorepair'):
     enable_autorepair = cmd_util.GetAutoRepair(args)
     if enable_autorepair:
@@ -214,6 +248,7 @@ def ParseCreateOptionsBase(args, is_autogke, get_default, location, project_id):
       enable_stackdriver_kubernetes=_GetEnableStackdriver(args),
       enable_cloud_logging=args.enable_cloud_logging if (hasattr(args, 'enable_cloud_logging') and args.IsSpecified('enable_cloud_logging')) else None,
       enable_cloud_monitoring=args.enable_cloud_monitoring if (hasattr(args, 'enable_cloud_monitoring') and args.IsSpecified('enable_cloud_monitoring')) else None,
+      enable_workload_monitoring_eap=get_default('enable_workload_monitoring_eap'),
       enable_ip_alias=enable_ip_alias,
       enable_intra_node_visibility=get_default('enable_intra_node_visibility'),
       enable_kubernetes_alpha=get_default('enable_kubernetes_alpha'),
@@ -257,6 +292,7 @@ def ParseCreateOptionsBase(args, is_autogke, get_default, location, project_id):
       services_ipv4_cidr=get_default('services_ipv4_cidr'),
       services_secondary_range_name=get_default('services_secondary_range_name'),
       subnetwork=get_default('subnetwork'),
+      private_ipv6_google_access_type=get_default('private_ipv6_google_access_type'),
       tags=get_default('tags'),
       user=get_default('username'),
       metadata=metadata,
@@ -336,7 +372,7 @@ def AddMasterSignalsFlag(parser):
 
 
 def AddPrivateIPv6Flag(api, parser):
-  flags.AddPrivateIpv6GoogleAccessTypeFlag(api, parser, hidden=True)
+  flags.AddPrivateIpv6GoogleAccessTypeFlag(api, parser)
 
 
 def AddKubernetesObjectsExportFlag(parser):
@@ -402,6 +438,7 @@ flags_to_add = {
         'num_nodes': flags.AddNumNodes,
         'preemptible': flags.AddPreemptibleFlag,
         'privatecluster': flags.AddPrivateClusterFlags,
+        'privateipv6type': (lambda p: AddPrivateIPv6Flag('v1', p)),
         'releasechannel': flags.AddReleaseChannelFlag,
         'reservationaffinity': flags.AddReservationAffinityFlags,
         'resourceusageexport': flags.AddResourceUsageExportFlags,
@@ -416,316 +453,174 @@ flags_to_add = {
         'workloadmetadata': flags.AddWorkloadMetadataFlag,
     },
     BETA: {
-        'accelerator':
-            flags.AddAcceleratorArgs,
-        'additionalzones':
-            _AddAdditionalZonesGroup,
-        'addons':
-            flags.AddBetaAddonsFlags,
-        'allowrouteoverlap':
-            flags.AddAllowRouteOverlapFlag,
-        'args':
-            _Args,
-        'autorepair':
-            AddAutoRepair,
-        'autoprovisioning':
-            AddAutoprovisioning,
-        'autoscalingprofiles':
-            flags.AddAutoscalingProfilesFlag,
-        'authenticatorsecurity':
-            flags.AddAuthenticatorSecurityGroupFlags,
-        'autoupgrade':
-            AddEnableAutoUpgradeWithDefault,
-        'basicauth':
-            flags.AddBasicAuthFlags,
-        'binauthz':
-            flags.AddEnableBinAuthzFlag,
-        'bootdiskkms':
-            flags.AddBootDiskKmsKeyFlag,
-        'cloudlogging':
-            flags.AddEnableCloudLogging,
-        'cloudmonitoring':
-            flags.AddEnableCloudMonitoring,
-        'cloudrunalpha':
-            flags.AddEnableCloudRunAlphaFlag,
-        'cloudrunconfig':
-            flags.AddCloudRunConfigFlag,
-        'clusterautoscaling':
-            flags.AddClusterAutoscalingFlags,
-        'clusterversion':
-            flags.AddClusterVersionFlag,
-        'confidentialnodes':
-            flags.AddEnableConfidentialNodesFlag,
-        'databaseencryption':
-            flags.AddDatabaseEncryptionFlag,
+        'accelerator': flags.AddAcceleratorArgs,
+        'additionalzones': _AddAdditionalZonesGroup,
+        'addons': flags.AddBetaAddonsFlags,
+        'allowrouteoverlap': flags.AddAllowRouteOverlapFlag,
+        'args': _Args,
+        'autorepair': AddAutoRepair,
+        'autoprovisioning': AddAutoprovisioning,
+        'autoscalingprofiles': flags.AddAutoscalingProfilesFlag,
+        'authenticatorsecurity': flags.AddAuthenticatorSecurityGroupFlags,
+        'autoupgrade': AddEnableAutoUpgradeWithDefault,
+        'basicauth': flags.AddBasicAuthFlags,
+        'binauthz': flags.AddEnableBinAuthzFlag,
+        'bootdiskkms': flags.AddBootDiskKmsKeyFlag,
+        'cloudlogging': flags.AddEnableCloudLogging,
+        'cloudmonitoring': flags.AddEnableCloudMonitoring,
+        'cloudrunalpha': flags.AddEnableCloudRunAlphaFlag,
+        'cloudrunconfig': flags.AddCloudRunConfigFlag,
+        'clusterautoscaling': flags.AddClusterAutoscalingFlags,
+        'clusterversion': flags.AddClusterVersionFlag,
+        'confidentialnodes': flags.AddEnableConfidentialNodesFlag,
+        'databaseencryption': flags.AddDatabaseEncryptionFlag,
         'datapath': (lambda p: flags.AddDatapathProviderFlag(p, hidden=True)),
-        'dataplanev2':
-            flags.AddDataplaneV2Flag,
-        'disabledefaultsnat':
-            AddDisableDefaultSnatFlagForClusterCreate,
-        'disksize':
-            flags.AddDiskSizeFlag,
-        'disktype':
-            flags.AddDiskTypeFlag,
-        'gcfs':
-            flags.AddEnableGcfsFlag,
-        'imageflags':
-            flags.AddImageFlagsCreate,
-        'intranodevisibility':
-            flags.AddEnableIntraNodeVisibilityFlag,
-        'ipalias':
-            flags.AddIpAliasCoreFlag,
-        'ipalias_additional':
-            flags.AddIPAliasRelatedFlags,
-        'issueclientcert':
-            flags.AddIssueClientCertificateFlag,
-        'istioconfig':
-            flags.AddIstioConfigFlag,
-        'kubernetesalpha':
-            flags.AddEnableKubernetesAlphaFlag,
-        'kubernetesobjectsexport':
-            AddKubernetesObjectsExportFlag,
-        'gvnic':
-            flags.AddEnableGvnicFlag,
-        'gkeoidc':
-            flags.AddGkeOidcFlag,
-        'localssds':
-            flags.AddLocalSSDsBetaFlags,
-        'loggingmonitoring':
-            flags.AddEnableLoggingMonitoringSystemOnlyFlag,
-        'labels':
-            flags.AddLabelsFlag,
-        'legacyauth':
-            flags.AddEnableLegacyAuthorizationFlag,
-        'machinetype':
-            flags.AddMachineTypeFlag,
-        'maintenancewindow':
-            flags.AddMaintenanceWindowGroup,
-        'masterglobalaccess':
-            flags.AddMasterGlobalAccessFlag,
-        'masterauth':
-            flags.AddMasterAuthorizedNetworksFlags,
-        'mastersignals':
-            AddMasterSignalsFlag,
-        'maxnodes':
-            flags.AddMaxNodesPerPool,
-        'maxpodspernode':
-            flags.AddMaxPodsPerNodeFlag,
+        'dataplanev2': flags.AddDataplaneV2Flag,
+        'disabledefaultsnat': AddDisableDefaultSnatFlagForClusterCreate,
+        'disksize': flags.AddDiskSizeFlag,
+        'disktype': flags.AddDiskTypeFlag,
+        'gcfs': flags.AddEnableGcfsFlag,
+        'imageflags': flags.AddImageFlagsCreate,
+        'intranodevisibility': flags.AddEnableIntraNodeVisibilityFlag,
+        'ipalias': flags.AddIpAliasCoreFlag,
+        'ipalias_additional': flags.AddIPAliasRelatedFlags,
+        'issueclientcert': flags.AddIssueClientCertificateFlag,
+        'istioconfig': flags.AddIstioConfigFlag,
+        'kubernetesalpha': flags.AddEnableKubernetesAlphaFlag,
+        'kubernetesobjectsexport': AddKubernetesObjectsExportFlag,
+        'gvnic': flags.AddEnableGvnicFlag,
+        'gkeoidc': flags.AddGkeOidcFlag,
+        'localssds': flags.AddLocalSSDsBetaFlags,
+        'loggingmonitoring': flags.AddEnableLoggingMonitoringSystemOnlyFlag,
+        'labels': flags.AddLabelsFlag,
+        'legacyauth': flags.AddEnableLegacyAuthorizationFlag,
+        'machinetype': flags.AddMachineTypeFlag,
+        'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'masterglobalaccess': flags.AddMasterGlobalAccessFlag,
+        'masterauth': flags.AddMasterAuthorizedNetworksFlags,
+        'mastersignals': AddMasterSignalsFlag,
+        'maxnodes': flags.AddMaxNodesPerPool,
+        'maxpodspernode': flags.AddMaxPodsPerNodeFlag,
         'maxunavailable':
             (lambda p: flags.AddMaxUnavailableUpgradeFlag(p, is_create=True)),
-        'metadata':
-            flags.AddMetadataFlags,
-        'mincpu':
-            flags.AddMinCpuPlatformFlag,
-        'networkpolicy':
-            flags.AddNetworkPolicyFlags,
-        'nodetaints':
-            flags.AddNodeTaintsFlag,
-        'nodeidentity':
-            flags.AddClusterNodeIdentityFlags,
-        'nodeversion':
-            flags.AddNodeVersionFlag,
-        'nodelabels':
-            flags.AddNodeLabelsFlag,
-        'notificationconfig':
-            flags.AddNotificationConfigFlag,
-        'num_nodes':
-            flags.AddNumNodes,
-        'podsecuritypolicy':
-            flags.AddPodSecurityPolicyFlag,
-        'preemptible':
-            flags.AddPreemptibleFlag,
-        'privatecluster':
-            AddPrivateClusterDeprecated,
+        'metadata': flags.AddMetadataFlags,
+        'mincpu': flags.AddMinCpuPlatformFlag,
+        'networkpolicy': flags.AddNetworkPolicyFlags,
+        'nodetaints': flags.AddNodeTaintsFlag,
+        'nodeidentity': flags.AddClusterNodeIdentityFlags,
+        'nodeversion': flags.AddNodeVersionFlag,
+        'nodelabels': flags.AddNodeLabelsFlag,
+        'notificationconfig': flags.AddNotificationConfigFlag,
+        'num_nodes': flags.AddNumNodes,
+        'podsecuritypolicy': flags.AddPodSecurityPolicyFlag,
+        'preemptible': flags.AddPreemptibleFlag,
+        'privatecluster': AddPrivateClusterDeprecated,
         'privateipv6type': (lambda p: AddPrivateIPv6Flag('v1beta1', p)),
-        'releasechannel':
-            flags.AddReleaseChannelFlag,
-        'resourceusageexport':
-            flags.AddResourceUsageExportFlags,
-        'reservationaffinity':
-            flags.AddReservationAffinityFlags,
-        'shieldedinstance':
-            flags.AddShieldedInstanceFlags,
-        'shieldednodes':
-            flags.AddEnableShieldedNodesFlags,
-        'stackdriver':
-            flags.AddEnableStackdriverKubernetesFlag,
+        'releasechannel': flags.AddReleaseChannelFlag,
+        'resourceusageexport': flags.AddResourceUsageExportFlags,
+        'reservationaffinity': flags.AddReservationAffinityFlags,
+        'shieldedinstance': flags.AddShieldedInstanceFlags,
+        'shieldednodes': flags.AddEnableShieldedNodesFlags,
+        'stackdriver': flags.AddEnableStackdriverKubernetesFlag,
         'surgeupgrade': (lambda p: flags.AddSurgeUpgradeFlag(p, default=1)),
-        'systemconfig':
-            lambda p: flags.AddSystemConfigFlag(p, hidden=False),
-        'tags':
-            flags.AddTagsCreate,
-        'tpu':
-            AddTpuWithServiceNetworking,
-        'verticalpodautoscaling':
-            flags.AddVerticalPodAutoscalingFlag,
-        'workloadidentity': (lambda p: flags.AddWorkloadIdentityFlags(p, True)),
-        'workloadmetadata':
-            (lambda p: flags.AddWorkloadMetadataFlag(p, use_mode=False)),
-    },
-    ALPHA: {
-        'accelerator':
-            flags.AddAcceleratorArgs,
-        'additionalzones':
-            _AddAdditionalZonesGroup,
-        'addons':
-            flags.AddAlphaAddonsFlags,
-        'allowrouteoverlap':
-            flags.AddAllowRouteOverlapFlag,
-        'args':
-            _Args,
-        'authenticatorsecurity':
-            flags.AddAuthenticatorSecurityGroupFlags,
-        'autoprovisioning':
-            AddAutoprovisioning,
-        'autorepair':
-            AddAutoRepair,
-        'autoscalingprofiles':
-            flags.AddAutoscalingProfilesFlag,
-        'basicauth':
-            flags.AddBasicAuthFlags,
-        'cloudlogging':
-            flags.AddEnableCloudLogging,
-        'clusterversion':
-            flags.AddClusterVersionFlag,
-        'autoupgrade':
-            AddEnableAutoUpgradeWithDefault,
-        'binauthz':
-            flags.AddEnableBinAuthzFlag,
-        'bootdiskkms':
-            flags.AddBootDiskKmsKeyFlag,
-        'cloudmonitoring':
-            flags.AddEnableCloudMonitoring,
-        'cloudrunalpha':
-            flags.AddEnableCloudRunAlphaFlag,
-        'cloudrunconfig':
-            flags.AddCloudRunConfigFlag,
-        'clusterautoscaling':
-            flags.AddClusterAutoscalingFlags,
-        'clusterdns':
-            flags.AddClusterDNSFlags,
-        'confidentialnodes':
-            flags.AddEnableConfidentialNodesFlag,
-        'costmanagementconfig':
-            flags.AddCostManagementConfigFlag,
-        'databaseencryption':
-            flags.AddDatabaseEncryptionFlag,
-        'datapath':
-            lambda p: flags.AddDatapathProviderFlag(p, hidden=True),
-        'dataplanev2':
-            flags.AddDataplaneV2Flag,
-        'disabledefaultsnat':
-            AddDisableDefaultSnatFlagForClusterCreate,
-        'disksize':
-            flags.AddDiskSizeFlag,
-        'disktype':
-            flags.AddDiskTypeFlag,
-        'gcfs':
-            flags.AddEnableGcfsFlag,
-        'gkeoidc':
-            flags.AddGkeOidcFlag,
-        'gvnic':
-            flags.AddEnableGvnicFlag,
-        'ilbsubsetting':
-            flags.AddILBSubsettingFlags,
-        'imageflags':
-            flags.AddImageFlagsCreate,
-        'intranodevisibility':
-            flags.AddEnableIntraNodeVisibilityFlag,
-        'ipalias':
-            flags.AddIpAliasCoreFlag,
-        'ipalias_additional':
-            flags.AddIPAliasRelatedFlags,
-        'issueclientcert':
-            flags.AddIssueClientCertificateFlag,
-        'istioconfig':
-            flags.AddIstioConfigFlag,
-        'kubernetesalpha':
-            flags.AddEnableKubernetesAlphaFlag,
-        'labels':
-            flags.AddLabelsFlag,
-        'legacyauth':
-            flags.AddEnableLegacyAuthorizationFlag,
-        'linuxsysctl':
-            flags.AddLinuxSysctlFlags,
-        'localssds':
-            flags.AddLocalSSDsAlphaFlags,
-        'loggingmonitoring':
-            flags.AddEnableLoggingMonitoringSystemOnlyFlag,
-        'machinetype':
-            flags.AddMachineTypeFlag,
-        'kubernetesobjectsexport':
-            AddKubernetesObjectsExportFlag,
-        'npname':
-            lambda p: flags.AddInitialNodePoolNameArg(p, hidden=False),
-        'maxunavailable':
-            (lambda p: flags.AddMaxUnavailableUpgradeFlag(p, is_create=True)),
-        'masterglobalaccess':
-            flags.AddMasterGlobalAccessFlag,
-        'maxnodes':
-            flags.AddMaxNodesPerPool,
-        'maxpodspernode':
-            flags.AddMaxPodsPerNodeFlag,
-        'maintenancewindow':
-            flags.AddMaintenanceWindowGroup,
-        'masterauth':
-            flags.AddMasterAuthorizedNetworksFlags,
-        'mastersignals':
-            AddMasterSignalsFlag,
-        'metadata':
-            flags.AddMetadataFlags,
-        'mincpu':
-            flags.AddMinCpuPlatformFlag,
-        'networkpolicy':
-            flags.AddNetworkPolicyFlags,
-        'nodetaints':
-            flags.AddNodeTaintsFlag,
-        'nodeidentity':
-            flags.AddClusterNodeIdentityFlags,
-        'nodeversion':
-            flags.AddNodeVersionFlag,
-        'nodelabels':
-            flags.AddNodeLabelsFlag,
-        'notificationconfig':
-            flags.AddNotificationConfigFlag,
-        'num_nodes':
-            flags.AddNumNodes,
-        'podsecuritypolicy':
-            flags.AddPodSecurityPolicyFlag,
-        'preemptible':
-            flags.AddPreemptibleFlag,
-        'privatecluster':
-            AddPrivateClusterDeprecated,
-        'privateipv6':
-            (lambda p: flags.AddEnablePrivateIpv6AccessFlag(p, hidden=True)),
-        'privateipv6type': (lambda p: AddPrivateIPv6Flag('v1alpha1', p)),
-        'reservationaffinity':
-            flags.AddReservationAffinityFlags,
-        'resourceusageexport':
-            flags.AddResourceUsageExportFlags,
-        'releasechannel':
-            flags.AddReleaseChannelFlag,
-        'shieldedinstance':
-            flags.AddShieldedInstanceFlags,
-        'shieldednodes':
-            flags.AddEnableShieldedNodesFlags,
-        'stackdriver':
-            flags.AddEnableStackdriverKubernetesFlag,
-        'securityprofile':
-            flags.AddSecurityProfileForCreateFlags,
-        'surgeupgrade': (lambda p: flags.AddSurgeUpgradeFlag(p, default=1)),
-        'systemconfig':
-            lambda p: flags.AddSystemConfigFlag(p, hidden=False),
-        'tags':
-            flags.AddTagsCreate,
-        'tpu':
-            AddTpuWithServiceNetworking,
-        'verticalpodautoscaling':
-            flags.AddVerticalPodAutoscalingFlag,
+        'systemconfig': lambda p: flags.AddSystemConfigFlag(p, hidden=False),
+        'tags': flags.AddTagsCreate,
+        'tpu': AddTpuWithServiceNetworking,
+        'verticalpodautoscaling': flags.AddVerticalPodAutoscalingFlag,
         'workloadidentity':
             (lambda p: flags.AddWorkloadIdentityFlags(p, True, True)),
         'workloadmetadata':
             (lambda p: flags.AddWorkloadMetadataFlag(p, use_mode=False)),
+        'workloadmonitoringeap': flags.AddEnableWorkloadMonitoringEapFlag,
+    },
+    ALPHA: {
+        'accelerator': flags.AddAcceleratorArgs,
+        'additionalzones': _AddAdditionalZonesGroup,
+        'addons': flags.AddAlphaAddonsFlags,
+        'allowrouteoverlap': flags.AddAllowRouteOverlapFlag,
+        'args': _Args,
+        'authenticatorsecurity': flags.AddAuthenticatorSecurityGroupFlags,
+        'autoprovisioning': AddAutoprovisioning,
+        'autorepair': AddAutoRepair,
+        'autoscalingprofiles': flags.AddAutoscalingProfilesFlag,
+        'basicauth': flags.AddBasicAuthFlags,
+        'cloudlogging': flags.AddEnableCloudLogging,
+        'clusterversion': flags.AddClusterVersionFlag,
+        'autoupgrade': AddEnableAutoUpgradeWithDefault,
+        'binauthz': flags.AddEnableBinAuthzFlag,
+        'bootdiskkms': flags.AddBootDiskKmsKeyFlag,
+        'cloudmonitoring': flags.AddEnableCloudMonitoring,
+        'cloudrunalpha': flags.AddEnableCloudRunAlphaFlag,
+        'cloudrunconfig': flags.AddCloudRunConfigFlag,
+        'clusterautoscaling': flags.AddClusterAutoscalingFlags,
+        'clusterdns': flags.AddClusterDNSFlags,
+        'confidentialnodes': flags.AddEnableConfidentialNodesFlag,
+        'costmanagementconfig': flags.AddCostManagementConfigFlag,
+        'databaseencryption': flags.AddDatabaseEncryptionFlag,
+        'datapath': lambda p: flags.AddDatapathProviderFlag(p, hidden=True),
+        'dataplanev2': flags.AddDataplaneV2Flag,
+        'disabledefaultsnat': AddDisableDefaultSnatFlagForClusterCreate,
+        'disksize': flags.AddDiskSizeFlag,
+        'disktype': flags.AddDiskTypeFlag,
+        'gcfs': flags.AddEnableGcfsFlag,
+        'gkeoidc': flags.AddGkeOidcFlag,
+        'gvnic': flags.AddEnableGvnicFlag,
+        'ilbsubsetting': flags.AddILBSubsettingFlags,
+        'imageflags': flags.AddImageFlagsCreate,
+        'intranodevisibility': flags.AddEnableIntraNodeVisibilityFlag,
+        'ipalias': flags.AddIpAliasCoreFlag,
+        'ipalias_additional': flags.AddIPAliasRelatedFlags,
+        'issueclientcert': flags.AddIssueClientCertificateFlag,
+        'istioconfig': flags.AddIstioConfigFlag,
+        'kubernetesalpha': flags.AddEnableKubernetesAlphaFlag,
+        'labels': flags.AddLabelsFlag,
+        'legacyauth': flags.AddEnableLegacyAuthorizationFlag,
+        'linuxsysctl': flags.AddLinuxSysctlFlags,
+        'localssds': flags.AddLocalSSDsAlphaFlags,
+        'loggingmonitoring': flags.AddEnableLoggingMonitoringSystemOnlyFlag,
+        'machinetype': flags.AddMachineTypeFlag,
+        'kubernetesobjectsexport': AddKubernetesObjectsExportFlag,
+        'npname': lambda p: flags.AddInitialNodePoolNameArg(p, hidden=False),
+        'maxunavailable':
+            (lambda p: flags.AddMaxUnavailableUpgradeFlag(p, is_create=True)),
+        'masterglobalaccess': flags.AddMasterGlobalAccessFlag,
+        'maxnodes': flags.AddMaxNodesPerPool,
+        'maxpodspernode': flags.AddMaxPodsPerNodeFlag,
+        'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'masterauth': flags.AddMasterAuthorizedNetworksFlags,
+        'mastersignals': AddMasterSignalsFlag,
+        'metadata': flags.AddMetadataFlags,
+        'mincpu': flags.AddMinCpuPlatformFlag,
+        'networkpolicy': flags.AddNetworkPolicyFlags,
+        'nodetaints': flags.AddNodeTaintsFlag,
+        'nodeidentity': flags.AddClusterNodeIdentityFlags,
+        'nodeversion': flags.AddNodeVersionFlag,
+        'nodelabels': flags.AddNodeLabelsFlag,
+        'notificationconfig': flags.AddNotificationConfigFlag,
+        'num_nodes': flags.AddNumNodes,
+        'podsecuritypolicy': flags.AddPodSecurityPolicyFlag,
+        'preemptible': flags.AddPreemptibleFlag,
+        'privatecluster': AddPrivateClusterDeprecated,
+        'privateipv6':
+            (lambda p: flags.AddEnablePrivateIpv6AccessFlag(p, hidden=True)),
+        'privateipv6type': (lambda p: AddPrivateIPv6Flag('v1alpha1', p)),
+        'reservationaffinity': flags.AddReservationAffinityFlags,
+        'resourceusageexport': flags.AddResourceUsageExportFlags,
+        'releasechannel': flags.AddReleaseChannelFlag,
+        'shieldedinstance': flags.AddShieldedInstanceFlags,
+        'shieldednodes': flags.AddEnableShieldedNodesFlags,
+        'stackdriver': flags.AddEnableStackdriverKubernetesFlag,
+        'securityprofile': flags.AddSecurityProfileForCreateFlags,
+        'surgeupgrade': (lambda p: flags.AddSurgeUpgradeFlag(p, default=1)),
+        'systemconfig': lambda p: flags.AddSystemConfigFlag(p, hidden=False),
+        'tags': flags.AddTagsCreate,
+        'tpu': AddTpuWithServiceNetworking,
+        'verticalpodautoscaling': flags.AddVerticalPodAutoscalingFlag,
+        'workloadidentity':
+            (lambda p: flags.AddWorkloadIdentityFlags(p, True, True)),
+        'workloadmetadata':
+            (lambda p: flags.AddWorkloadMetadataFlag(p, use_mode=False)),
+        'workloadmonitoringeap': flags.AddEnableWorkloadMonitoringEapFlag,
     },
 }
 
@@ -835,6 +730,11 @@ class Create(base.CreateCommand):
             'Your Pod address range (`--cluster-ipv4-cidr`) can accommodate at most %d node(s). '
             % max_node_number)
 
+    if not options.image_type:
+      log.warning(
+          'Starting with version 1.19, newly created clusters and node-pools will have COS_CONTAINERD as the default node image when no image type is specified.'
+      )
+
     if options.enable_kubernetes_alpha:
       console_io.PromptContinue(
           message=constants.KUBERNETES_ALPHA_PROMPT,
@@ -918,14 +818,17 @@ class CreateBeta(Create):
     ops.enable_master_metrics = get_default('enable_master_metrics')
     ops.master_logs = get_default('master_logs')
     ops.notification_config = get_default('notification_config')
-    ops.private_ipv6_google_access_type = \
-        get_default('private_ipv6_google_access_type')
     ops.enable_confidential_nodes = get_default('enable_confidential_nodes')
     ops.kubernetes_objects_changes_target = \
         getattr(args, 'kubernetes_objects_changes_target', None)
     ops.kubernetes_objects_snapshots_target = \
         getattr(args, 'kubernetes_objects_snapshots_target', None)
     ops.enable_gcfs = get_default('enable_gcfs')
+    ops.workload_identity_certificate_authority = get_default(
+        'workload_identity_certificate_authority')
+    ops.ephemeral_storage = get_default('ephemeral_storage')
+    ops.enable_workload_monitoring_eap = \
+      get_default('enable_workload_monitoring_eap')
     return ops
 
 
@@ -947,6 +850,7 @@ class CreateAlpha(Create):
     ops.boot_disk_kms_key = get_default('boot_disk_kms_key')
     ops.autoscaling_profile = get_default('autoscaling_profile')
     ops.local_ssd_volume_configs = get_default('local_ssd_volumes')
+    ops.ephemeral_storage = get_default('ephemeral_storage')
     ops.enable_pod_security_policy = get_default('enable_pod_security_policy')
     ops.allow_route_overlap = get_default('allow_route_overlap')
     ops.private_cluster = get_default('private_cluster')
@@ -985,8 +889,6 @@ class CreateAlpha(Create):
     ops.enable_master_metrics = get_default('enable_master_metrics')
     ops.master_logs = get_default('master_logs')
     ops.notification_config = get_default('notification_config')
-    ops.private_ipv6_google_access_type = \
-        get_default('private_ipv6_google_access_type')
     ops.enable_confidential_nodes = get_default('enable_confidential_nodes')
     ops.cluster_dns = get_default('cluster_dns')
     ops.cluster_dns_scope = get_default('cluster_dns_scope')
@@ -998,4 +900,6 @@ class CreateAlpha(Create):
     ops.enable_gcfs = get_default('enable_gcfs')
     ops.workload_identity_certificate_authority = get_default(
         'workload_identity_certificate_authority')
+    ops.enable_workload_monitoring_eap = \
+      get_default('enable_workload_monitoring_eap')
     return ops
