@@ -292,6 +292,7 @@ class Update(base.UpdateCommand):
     flags.AddAutoprovisioningFlags(group)
     flags.AddEnableShieldedNodesFlags(group)
     flags.AddMasterGlobalAccessFlag(group, is_update=True)
+    flags.AddPrivateIpv6GoogleAccessTypeFlag('v1', group, hidden=False)
 
   def ParseUpdateOptions(self, args, locations):
     opts = container_command_util.ParseUpdateOptionsBase(args, locations)
@@ -575,6 +576,7 @@ class UpdateBeta(Update):
     flags.AddMonitoringServiceFlag(group_logging_monitoring)
     flags.AddEnableStackdriverKubernetesFlag(group)
     flags.AddEnableLoggingMonitoringSystemOnlyFlag(group)
+    flags.AddEnableWorkloadMonitoringEapFlag(group)
     flags.AddEnableMasterSignalsFlags(group)
     flags.AddMasterAuthorizedNetworksFlags(
         parser, enable_group_for_update=group)
@@ -597,8 +599,9 @@ class UpdateBeta(Update):
     flags.AddIstioConfigFlag(parser)
     flags.AddCloudRunConfigFlag(parser)
     flags.AddEnableIntraNodeVisibilityFlag(group)
-    flags.AddWorkloadIdentityFlags(group, use_identity_provider=True)
-    flags.AddWorkloadIdentityUpdateFlags(group)
+    flags.AddWorkloadIdentityFlags(
+        group, use_identity_provider=True, use_workload_certificates=True)
+    flags.AddWorkloadIdentityUpdateFlags(group, use_workload_certificates=True)
     flags.AddGkeOidcFlag(group)
     flags.AddDatabaseEncryptionFlag(group)
     flags.AddDisableDatabaseEncryptionFlag(group)
@@ -609,7 +612,7 @@ class UpdateBeta(Update):
     flags.AddEnableGvnicFlag(group)
     flags.AddDisableDefaultSnatFlag(group, for_cluster_create=False)
     flags.AddNotificationConfigFlag(group)
-    flags.AddPrivateIpv6GoogleAccessTypeFlag('v1beta1', group, hidden=True)
+    flags.AddPrivateIpv6GoogleAccessTypeFlag('v1beta1', group, hidden=False)
     flags.AddKubernetesObjectsExportConfig(group)
 
   def ParseUpdateOptions(self, args, locations):
@@ -624,6 +627,8 @@ class UpdateBeta(Update):
         args.clear_resource_usage_bigquery_dataset
     opts.enable_network_egress_metering = args.enable_network_egress_metering
     opts.enable_resource_consumption_metering = args.enable_resource_consumption_metering
+    opts.workload_identity_certificate_authority = args.workload_identity_certificate_authority
+    opts.disable_workload_identity_certificates = args.disable_workload_identity_certificates
     flags.ValidateIstioConfigUpdateArgs(args.istio_config, args.disable_addons)
     flags.ValidateCloudRunConfigUpdateArgs(args.cloud_run_config,
                                            args.disable_addons)
@@ -666,10 +671,10 @@ class UpdateBeta(Update):
     opts.enable_gvnic = args.enable_gvnic
     opts.disable_default_snat = args.disable_default_snat
     opts.notification_config = args.notification_config
-    opts.private_ipv6_google_access_type = args.private_ipv6_google_access_type
     opts.kubernetes_objects_changes_target = args.kubernetes_objects_changes_target
     opts.kubernetes_objects_snapshots_target = args.kubernetes_objects_snapshots_target
     opts.enable_gke_oidc = args.enable_gke_oidc
+    opts.enable_workload_monitoring_eap = args.enable_workload_monitoring_eap
 
     return opts
 
@@ -692,6 +697,7 @@ class UpdateAlpha(Update):
     flags.AddMonitoringServiceFlag(group_logging_monitoring)
     flags.AddEnableStackdriverKubernetesFlag(group)
     flags.AddEnableLoggingMonitoringSystemOnlyFlag(group)
+    flags.AddEnableWorkloadMonitoringEapFlag(group)
     flags.AddEnableMasterSignalsFlags(group)
     flags.AddMasterAuthorizedNetworksFlags(
         parser, enable_group_for_update=group)
@@ -729,7 +735,7 @@ class UpdateAlpha(Update):
     flags.AddMasterGlobalAccessFlag(group, is_update=True)
     flags.AddEnableGvnicFlag(group)
     flags.AddNotificationConfigFlag(group)
-    flags.AddPrivateIpv6GoogleAccessTypeFlag('v1alpha1', group, hidden=True)
+    flags.AddPrivateIpv6GoogleAccessTypeFlag('v1alpha1', group, hidden=False)
     flags.AddKubernetesObjectsExportConfig(group)
 
   def ParseUpdateOptions(self, args, locations):
@@ -789,9 +795,9 @@ class UpdateAlpha(Update):
     opts.enable_master_global_access = args.enable_master_global_access
     opts.enable_gvnic = args.enable_gvnic
     opts.notification_config = args.notification_config
-    opts.private_ipv6_google_access_type = args.private_ipv6_google_access_type
     opts.kubernetes_objects_changes_target = args.kubernetes_objects_changes_target
     opts.kubernetes_objects_snapshots_target = args.kubernetes_objects_snapshots_target
     opts.enable_gke_oidc = args.enable_gke_oidc
+    opts.enable_workload_monitoring_eap = args.enable_workload_monitoring_eap
 
     return opts
