@@ -12,12 +12,13 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""Command to list available Kuberun resources."""
+"""Command to render Kuberun resources to yaml."""
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.calliope import base
+from googlecloudsdk.command_lib.kuberun import flags
 from googlecloudsdk.command_lib.kuberun import kuberun_command
 
 _DETAILED_HELP = {
@@ -29,11 +30,25 @@ _DETAILED_HELP = {
 }
 
 
+def _OutFlag():
+  return flags.StringFlag(
+      '--out',
+      help='Output directory for rendered resource yaml.',
+      required=True)
+
+
+def _EnvironmentFlag():
+  return flags.StringFlag(
+      '--environment',
+      help='Name of the environment to which KubeRun will deploy.',
+      required=True)
+
+
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class Render(kuberun_command.KubeRunStreamingCommand, base.ExportCommand):
   """Render KubeRun application to generate the yaml resource configuration."""
   detailed_help = _DETAILED_HELP
-  flags = []
+  flags = [_OutFlag(), _EnvironmentFlag()]
 
   def Command(self):
     return ['render']
