@@ -21,7 +21,7 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
+@base.ReleaseTracks(base.ReleaseTrack.BETA, base.ReleaseTrack.GA)
 class CloudSecrets(base.Group):
   """Manage secrets on Google Cloud.
 
@@ -48,3 +48,4 @@ class CloudSecrets(base.Group):
     # This is technically the default, but some gcloud commands like IAM have
     # user project override off by default, so we enable it here explicitly.
     base.EnableUserProjectQuota()
+    base.OptInRequests()
